@@ -1,8 +1,7 @@
 test_that("bird-species works", {
 
   dataset <- bird_species_dataset(
-    root = tempfile(),
-    token = "kaggle.json",
+    root = "./bird",
     download = TRUE
   )
 
